@@ -20,7 +20,7 @@ our $VERSION;
 our $DEBUG;
 
 BEGIN {
-  our $VERSION = qv(8.5.6);
+  our $VERSION = qv(8.5.7);
   XSLoader::load("sealed", $VERSION);
 }
 
@@ -194,17 +194,15 @@ sub import {
   $DEBUG                         = $_[1];
   local $@;
   my $pkg                        = caller;
-  eval "package $pkg; use types; use class" if $DEBUG eq 'types'; # enable perl type system
+  eval "package $pkg; use types; use class"
+    if $DEBUG eq 'types'; # enable perl type system
   die $@ if $@;
   filter_add(bless []);
 }
 
-sub filter {
-  my ($self) = @_;
-  my $status = filter_read;
-  our %rcache;
-  my $pkg = caller;
-
+sub source_munger {
+  my $pkg = shift;
+  my $status = shift;
   # NEW in v8.x.y: handle signatures
   no warnings 'uninitialized';
   s(^
@@ -252,7 +250,12 @@ sub filter {
   s/(^|;)\s*my\s+(\w[\w:]*)\s+(\$\w+)(.)/$4 eq ";"
     ? qq($1BEGIN{local \$@; eval "require $2"} my $2 $3$4 {no strict qw!vars subs!; no warnings 'once'; $3 = $2})
     : qq($1BEGIN{local \$@; eval "require $2"} my $2 $3$4)/gmse if $status > 0;
+}
 
+sub filter {
+  my ($self) = @_;
+  my $status = filter_read;
+  source_munger scalar(caller), $status;
   return $status;
 }
 
@@ -284,8 +287,6 @@ sealed - Subroutine attribute for compile-time method lookups on its typed lexic
     use sealed 'types';   # enables builtin Perl::Types type system optimizations
     use sealed;           # disables all warnings
 
-    NOTE: as of 8.5.0, import activates the Perl Type System automatically.
-
 =head1 BUGS
 
 You may need to simplify your named method call argument stack,
